@@ -1,5 +1,3 @@
-from pathlib import Path
-
 import click
 
 from indico_install.cluster_manager import (
@@ -7,14 +5,15 @@ from indico_install.cluster_manager import (
     get_services_yaml_from_tag,
     list_backups,
 )
-from indico_install.config import merge_dicts, yaml
+from indico_install.config import merge_dicts, yaml, INPUT_YAML
 from indico_install.helm.apply import apply
 from indico_install.helm.render import render
+from indico_install.setup import configure_gcr_key, setup
 from indico_install.utils import options_wrapper, pretty_diff, string_to_tag
 
 
 def refresh_cluster_manager(
-    ctx, cluster_manager, deployment_root, yes, allow_image_overrides=False
+    ctx, cluster_manager, yes, allow_image_overrides=False
 ):
     """
     Given recent changes, apply them to the cluster
@@ -24,13 +23,11 @@ def refresh_cluster_manager(
         ctx.invoke(
             render,
             cluster_manager=cluster_manager,
-            deployment_root=deployment_root,
             allow_image_overrides=allow_image_overrides,
         )
         ctx.invoke(
             apply,
             cluster_manager=cluster_manager,
-            deployment_root=deployment_root,
             yes=yes,
         )
     finally:
@@ -97,12 +94,10 @@ def show_current(ctx):
 )
 @click.option("--patch-file", type=click.File("r"), help="YAML-formatted patch file")
 @options_wrapper()
-def edit_configmap(ctx, *, force, patch_file, version, yes, deployment_root, **kwargs):
+def edit_configmap(ctx, *, force, patch_file, version, yes, **kwargs):
     """
     Edit configmap interactively or through a patch file.
     Only allows editing of the main cluster config portion
-
-    ex: indico updraft edit '{"apiDomain": "api-foo.indico.io"}'
     """
     cluster_manager = ClusterManager()
     if not cluster_manager.cm_exists:
@@ -151,7 +146,6 @@ def edit_configmap(ctx, *, force, patch_file, version, yes, deployment_root, **k
         refresh_cluster_manager(
             ctx,
             cluster_manager,
-            deployment_root,
             yes,
             allow_image_overrides=not version,
         )
@@ -161,7 +155,7 @@ def edit_configmap(ctx, *, force, patch_file, version, yes, deployment_root, **k
 @click.pass_context
 @click.option("--keep-images", is_flag=True, help="Keep the current deployed images")
 @options_wrapper()
-def restore_version(ctx, deployment_root, yes, keep_images=False):
+def restore_version(ctx, yes, keep_images=False):
     """
     (Alpha) If backups of the cluster_manager exist, choose and restore
     to a specific backup
@@ -198,26 +192,26 @@ def restore_version(ctx, deployment_root, yes, keep_images=False):
 
     if yes or click.confirm("Save and apply backup? "):
         refresh_cluster_manager(
-            ctx, cluster_manager, deployment_root, yes, allow_image_overrides=True
+            ctx, cluster_manager, yes, allow_image_overrides=True
         )
 
 
 @updraft.command("init")
 @click.pass_context
-@options_wrapper()
-def init_tracking(ctx, input_yaml=None, yes=False, **kwargs):
+def init_tracking(ctx, yes=False, input_yaml=None):
     """
     Add or update version tracking to the cluster (idempotent)
     """
-    if input_yaml and not Path(input_yaml).is_file():
-        click.secho(
-            f"Provided input yaml {input_yaml} does not exist. Ignoring", fg="yellow"
-        )
-        input_yaml = None
+    if not input_yaml:
+        input_yaml = INPUT_YAML if INPUT_YAML.is_file() else None
+    if input_yaml:
+        setup(input_yaml)
     cluster_manager = ClusterManager(reconcile=True, input_yaml=input_yaml)
     click.secho(cluster_manager.to_str())
+
     if yes or click.confirm("Save updated version cluster_manager?"):
         cluster_manager.save()
+    configure_gcr_key()
 
 
 @updraft.command("diff")
@@ -252,3 +246,11 @@ def compare_versions(ctx, versions=None, show_all=False):
         diff = cluster_manager.diff_version(tag=versions[0] if versions else None)
 
     pretty_diff(diff, show_all=show_all)
+
+
+@updraft.command("clear-lock")
+@click.pass_context
+def clear_lock(ctx, versions=None, show_all=False):
+    """Force clears and existing CM lock"""
+    ClusterManager().unlock(force=True)
+    click.secho("Cluster Manager unlocked", fg="green")
